==> opensaml-saml-impl-3.3.1-sources.jar: org/opensaml/saml/saml2/metadata/impl/OrganizationDisplayNameImpl.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * 
 */

package org.opensaml.saml.saml2.metadata.impl;

import org.opensaml.saml.saml2.metadata.OrganizationDisplayName;

/**
 * Concrete implementation of {@link org.opensaml.saml.saml2.metadata.OrganizationDisplayName}.
 */
public class OrganizationDisplayNameImpl extends LocalizedNameImpl implements OrganizationDisplayName {

    /**
     * Constructor.
     * 
     * @param namespaceURI the namespace
     * @param elementLocalName the name
     * @param namespacePrefix the prefix
     */
    protected OrganizationDisplayNameImpl(String namespaceURI, String elementLocalName, String namespacePrefix) {
        super(namespaceURI, elementLocalName, namespacePrefix);
    }
}

==> opensaml-saml-impl-3.4.0-sources.jar: org/opensaml/saml/saml2/metadata/impl/OrganizationDisplayNameImpl.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * 
 */

package org.opensaml.saml.saml2.metadata.impl;

import org.opensaml.saml.saml2.metadata.OrganizationDisplayName;

/**
 * Concrete implementation of {@link org.opensaml.saml.saml2.metadata.OrganizationDisplayName}.
 */
public class OrganizationDisplayNameImpl extends LocalizedNameImpl implements OrganizationDisplayName {

    /**
     * Constructor.
     * 
     * @param namespaceURI the namespace
     * @param elementLocalName the name
     * @param namespacePrefix the prefix
     */
    protected OrganizationDisplayNameImpl(final String namespaceURI, final String elementLocalName,
            final String namespacePrefix) {
        super(namespaceURI, elementLocalName, namespacePrefix);
    }
}
